SevenSegmentPins

Struct SevenSegmentPins 

pub struct SevenSegmentPins<A, B, C, D, E, F, G> {
    pub a: A,
    pub b: B,
    pub c: C,
    pub d: D,
    pub e: E,
    pub f: F,
    pub g: G,
}
Pins of the 7-sement display

Pin arrangment:

 ________
|\__a___/|
| |    | |
|f|    |b|
| |____| |
|/  g   \|
|\______/|
| |    | |
|e|    |c|
| |____| |
|/__d___\|

Fields

a: A

Upper horizontal bar

b: B

Upper right vertical bar

c: C

Lower right vertical bar

d: D

Lower horizontal bar

e: E

Lower left vertical bar

f: F

Upper left vertival bar

g: G

Middle horizontal bar

Implementations

Source

impl<A, B, C, D, E, F, G> SevenSegmentPins<A, B, C, D, E, F, G>

pub fn with_common<Common: Polarity>( self, ) -> SevenSegment<A, B, C, D, E, F, G, Common>

Constructs SevenSegment with specified polarity.

pub fn with_common_cathode(self) -> SevenSegment<A, B, C, D, E, F, G, Cathode>

Shorthand for with_common::<Cathode>().

This prevents you from having to import Cathode or write with_common::<seven_segment::Cathode>()

pub fn with_common_anode(self) -> SevenSegment<A, B, C, D, E, F, G, Anode>

Shorthand for with_common::<Anode>().

This prevents you from having to import Anode or write with_common::<seven_segment::Anode>()