pub struct SevenSegmentPins<A, B, C, D, E, F, G> {
pub a: A,
pub b: B,
pub c: C,
pub d: D,
pub e: E,
pub f: F,
pub g: G,
}Expand description
Pins of the 7-sement display
Pin arrangment:
________
|\__a___/|
| | | |
|f| |b|
| |____| |
|/ g \|
|\______/|
| | | |
|e| |c|
| |____| |
|/__d___\|Fields
a: AUpper horizontal bar
b: BUpper right vertical bar
c: CLower right vertical bar
d: DLower horizontal bar
e: ELower left vertical bar
f: FUpper left vertival bar
g: GMiddle horizontal bar
Implementations
Sourceimpl<A, B, C, D, E, F, G> SevenSegmentPins<A, B, C, D, E, F, G>
impl<A, B, C, D, E, F, G> SevenSegmentPins<A, B, C, D, E, F, G>
Sourcepub fn with_common<Common: Polarity>(
self,
) -> SevenSegment<A, B, C, D, E, F, G, Common>
pub fn with_common<Common: Polarity>( self, ) -> SevenSegment<A, B, C, D, E, F, G, Common>
Constructs SevenSegment with specified polarity.
Sourcepub fn with_common_cathode(self) -> SevenSegment<A, B, C, D, E, F, G, Cathode>
pub fn with_common_cathode(self) -> SevenSegment<A, B, C, D, E, F, G, Cathode>
Shorthand for with_common::<Cathode>().
This prevents you from having to import Cathode or write
with_common::<seven_segment::Cathode>()
Sourcepub fn with_common_anode(self) -> SevenSegment<A, B, C, D, E, F, G, Anode>
pub fn with_common_anode(self) -> SevenSegment<A, B, C, D, E, F, G, Anode>
Shorthand for with_common::<Anode>().
This prevents you from having to import Anode or write
with_common::<seven_segment::Anode>()